# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/exchange/v1beta1/events.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2
from injective.exchange.v1beta1 import exchange_pb2 as injective_dot_exchange_dot_v1beta1_dot_exchange__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/exchange/v1beta1/events.proto',
  package='injective.exchange.v1beta1',
  syntax='proto3',
  serialized_options=b'ZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'injective/exchange/v1beta1/events.proto\x12\x1ainjective.exchange.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a%injective/oracle/v1beta1/oracle.proto\x1a)injective/exchange/v1beta1/exchange.proto\"\xb4\x01\n\x17\x45ventBatchSpotExecution\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x0e\n\x06is_buy\x18\x02 \x01(\x08\x12@\n\rexecutionType\x18\x03 \x01(\x0e\x32).injective.exchange.v1beta1.ExecutionType\x12\x34\n\x06trades\x18\x04 \x03(\x0b\x32$.injective.exchange.v1beta1.TradeLog\"\xa8\x02\n\x1d\x45ventBatchDerivativeExecution\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x0e\n\x06is_buy\x18\x02 \x01(\x08\x12\x16\n\x0eis_liquidation\x18\x03 \x01(\x08\x12J\n\x12\x63umulative_funding\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12@\n\rexecutionType\x18\x05 \x01(\x0e\x32).injective.exchange.v1beta1.ExecutionType\x12>\n\x06trades\x18\x06 \x03(\x0b\x32..injective.exchange.v1beta1.DerivativeTradeLog\"\x81\x02\n\x1d\x45ventLostFundsFromLiquidation\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\x0c\x12_\n\'lost_funds_from_available_during_payout\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12U\n\x1dlost_funds_from_order_cancels\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"t\n\x1c\x45ventBatchDerivativePosition\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x41\n\tpositions\x18\x02 \x03(\x0b\x32..injective.exchange.v1beta1.SubaccountPosition\"\x7f\n\x1b\x45ventDerivativeMarketPaused\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x14\n\x0csettle_price\x18\x02 \x01(\t\x12\x1b\n\x13total_missing_funds\x18\x03 \x01(\t\x12\x1a\n\x12missing_funds_rate\x18\x04 \x01(\t\"g\n\x1e\x45ventBinaryOptionsMarketUpdate\x12\x45\n\x06market\x18\x01 \x01(\x0b\x32/.injective.exchange.v1beta1.BinaryOptionsMarketB\x04\xc8\xde\x1f\x00\"\xa8\x01\n\x12\x45ventNewSpotOrders\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12>\n\nbuy_orders\x18\x02 \x03(\x0b\x32*.injective.exchange.v1beta1.SpotLimitOrder\x12?\n\x0bsell_orders\x18\x03 \x03(\x0b\x32*.injective.exchange.v1beta1.SpotLimitOrder\"\xba\x01\n\x18\x45ventNewDerivativeOrders\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x44\n\nbuy_orders\x18\x02 \x03(\x0b\x32\x30.injective.exchange.v1beta1.DerivativeLimitOrder\x12\x45\n\x0bsell_orders\x18\x03 \x03(\x0b\x32\x30.injective.exchange.v1beta1.DerivativeLimitOrder\"j\n\x14\x45ventCancelSpotOrder\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12?\n\x05order\x18\x02 \x01(\x0b\x32*.injective.exchange.v1beta1.SpotLimitOrderB\x04\xc8\xde\x1f\x00\"U\n\x15\x45ventSpotMarketUpdate\x12<\n\x06market\x18\x01 \x01(\x0b\x32&.injective.exchange.v1beta1.SpotMarketB\x04\xc8\xde\x1f\x00\"\x81\x02\n\x1a\x45ventPerpetualMarketUpdate\x12\x42\n\x06market\x18\x01 \x01(\x0b\x32,.injective.exchange.v1beta1.DerivativeMarketB\x04\xc8\xde\x1f\x00\x12T\n\x15perpetual_market_info\x18\x02 \x01(\x0b\x32/.injective.exchange.v1beta1.PerpetualMarketInfoB\x04\xc8\xde\x1f\x01\x12I\n\x07\x66unding\x18\x03 \x01(\x0b\x32\x32.injective.exchange.v1beta1.PerpetualMarketFundingB\x04\xc8\xde\x1f\x01\"\xc3\x01\n\x1e\x45ventExpiryFuturesMarketUpdate\x12\x42\n\x06market\x18\x01 \x01(\x0b\x32,.injective.exchange.v1beta1.DerivativeMarketB\x04\xc8\xde\x1f\x00\x12]\n\x1a\x65xpiry_futures_market_info\x18\x03 \x01(\x0b\x32\x33.injective.exchange.v1beta1.ExpiryFuturesMarketInfoB\x04\xc8\xde\x1f\x01\"\xa6\x02\n!EventPerpetualMarketFundingUpdate\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12I\n\x07\x66unding\x18\x02 \x01(\x0b\x32\x32.injective.exchange.v1beta1.PerpetualMarketFundingB\x04\xc8\xde\x1f\x00\x12\x19\n\x11is_hourly_funding\x18\x03 \x01(\x08\x12\x44\n\x0c\x66unding_rate\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12\x42\n\nmark_price\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\"u\n\x16\x45ventSubaccountDeposit\x12\x13\n\x0bsrc_address\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\x0c\x12/\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"v\n\x17\x45ventSubaccountWithdraw\x12\x15\n\rsubaccount_id\x18\x01 \x01(\x0c\x12\x13\n\x0b\x64st_address\x18\x02 \x01(\t\x12/\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"\x87\x01\n\x1e\x45ventSubaccountBalanceTransfer\x12\x19\n\x11src_subaccount_id\x18\x01 \x01(\t\x12\x19\n\x11\x64st_subaccount_id\x18\x02 \x01(\t\x12/\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"]\n\x17\x45ventBatchDepositUpdate\x12\x42\n\x0f\x64\x65posit_updates\x18\x01 \x03(\x0b\x32).injective.exchange.v1beta1.DepositUpdate\"\xb5\x01\n\x1b\x44\x65rivativeMarketOrderCancel\x12M\n\x0cmarket_order\x18\x01 \x01(\x0b\x32\x31.injective.exchange.v1beta1.DerivativeMarketOrderB\x04\xc8\xde\x1f\x01\x12G\n\x0f\x63\x61ncel_quantity\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\xef\x01\n\x1a\x45ventCancelDerivativeOrder\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x15\n\risLimitCancel\x18\x02 \x01(\x08\x12K\n\x0blimit_order\x18\x03 \x01(\x0b\x32\x30.injective.exchange.v1beta1.DerivativeLimitOrderB\x04\xc8\xde\x1f\x01\x12Z\n\x13market_order_cancel\x18\x04 \x01(\x0b\x32\x37.injective.exchange.v1beta1.DerivativeMarketOrderCancelB\x04\xc8\xde\x1f\x01\"]\n\x18\x45ventFeeDiscountSchedule\x12\x41\n\x08schedule\x18\x01 \x01(\x0b\x32/.injective.exchange.v1beta1.FeeDiscountSchedule\"\xbf\x01\n EventTradingRewardCampaignUpdate\x12L\n\rcampaign_info\x18\x01 \x01(\x0b\x32\x35.injective.exchange.v1beta1.TradingRewardCampaignInfo\x12M\n\x15\x63\x61mpaign_reward_pools\x18\x02 \x03(\x0b\x32..injective.exchange.v1beta1.CampaignRewardPool\"e\n\x1e\x45ventTradingRewardDistribution\x12\x43\n\x0f\x61\x63\x63ount_rewards\x18\x01 \x03(\x0b\x32*.injective.exchange.v1beta1.AccountRewards\"\x94\x01\n\"EventNewConditionalDerivativeOrder\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12:\n\x05order\x18\x02 \x01(\x0b\x32+.injective.exchange.v1beta1.DerivativeOrder\x12\x0c\n\x04hash\x18\x03 \x01(\x0c\x12\x11\n\tis_market\x18\x04 \x01(\x08\"\xed\x01\n%EventCancelConditionalDerivativeOrder\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x15\n\risLimitCancel\x18\x02 \x01(\x08\x12K\n\x0blimit_order\x18\x03 \x01(\x0b\x32\x30.injective.exchange.v1beta1.DerivativeLimitOrderB\x04\xc8\xde\x1f\x01\x12M\n\x0cmarket_order\x18\x04 \x01(\x0b\x32\x31.injective.exchange.v1beta1.DerivativeMarketOrderB\x04\xc8\xde\x1f\x01\"\x8c\x01\n&EventConditionalDerivativeOrderTrigger\x12\x11\n\tmarket_id\x18\x01 \x01(\x0c\x12\x16\n\x0eisLimitTrigger\x18\x02 \x01(\x08\x12\x1c\n\x14triggered_order_hash\x18\x03 \x01(\x0c\x12\x19\n\x11placed_order_hash\x18\x04 \x01(\x0c\"@\n\x0e\x45ventOrderFail\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0c\x12\x0e\n\x06hashes\x18\x02 \x03(\x0c\x12\r\n\x05\x66lags\x18\x03 \x03(\rBPZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,injective_dot_oracle_dot_v1beta1_dot_oracle__pb2.DESCRIPTOR,injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.DESCRIPTOR,])




_EVENTBATCHSPOTEXECUTION = _descriptor.Descriptor(
  name='EventBatchSpotExecution',
  full_name='injective.exchange.v1beta1.EventBatchSpotExecution',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.EventBatchSpotExecution.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_buy', full_name='injective.exchange.v1beta1.EventBatchSpotExecution.is_buy', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='executionType', full_name='injective.exchange.v1beta1.EventBatchSpotExecution.executionType', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trades', full_name='injective.exchange.v1beta1.EventBatchSpotExecution.trades', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=208,
  serialized_end=388,
)


_EVENTBATCHDERIVATIVEEXECUTION = _descriptor.Descriptor(
  name='EventBatchDerivativeExecution',
  full_name='injective.exchange.v1beta1.EventBatchDerivativeExecution',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.EventBatchDerivativeExecution.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_buy', full_name='injective.exchange.v1beta1.EventBatchDerivativeExecution.is_buy', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_liquidation', full_name='injective.exchange.v1beta1.EventBatchDerivativeExecution.is_liquidation', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cumulative_funding', full_name='injective.exchange.v1beta1.EventBatchDerivativeExecution.cumulative_funding', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='executionType', full_name='injective.exchange.v1beta1.EventBatchDerivativeExecution.executionType', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trades', full_name='injective.exchange.v1beta1.EventBatchDerivativeExecution.trades', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=391,
  serialized_end=687,
)


_EVENTLOSTFUNDSFROMLIQUIDATION = _descriptor.Descriptor(
  name='EventLostFundsFromLiquidation',
  full_name='injective.exchange.v1beta1.EventLostFundsFromLiquidation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.EventLostFundsFromLiquidation.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.EventLostFundsFromLiquidation.subaccount_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lost_funds_from_available_during_payout', full_name='injective.exchange.v1beta1.EventLostFundsFromLiquidation.lost_funds_from_available_during_payout', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lost_funds_from_order_cancels', full_name='injective.exchange.v1beta1.EventLostFundsFromLiquidation.lost_funds_from_order_cancels', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=690,
  serialized_end=947,
)


_EVENTBATCHDERIVATIVEPOSITION = _descriptor.Descriptor(
  name='EventBatchDerivativePosition',
  full_name='injective.exchange.v1beta1.EventBatchDerivativePosition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.EventBatchDerivativePosition.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='positions', full_name='injective.exchange.v1beta1.EventBatchDerivativePosition.positions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=949,
  serialized_end=1065,
)


_EVENTDERIVATIVEMARKETPAUSED = _descriptor.Descriptor(
  name='EventDerivativeMarketPaused',
  full_name='injective.exchange.v1beta1.EventDerivativeMarketPaused',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.EventDerivativeMarketPaused.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settle_price', full_name='injective.exchange.v1beta1.EventDerivativeMarketPaused.settle_price', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_missing_funds', full_name='injective.exchange.v1beta1.EventDerivativeMarketPaused.total_missing_funds', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='missing_funds_rate', full_name='injective.exchange.v1beta1.EventDerivativeMarketPaused.missing_funds_rate', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1067,
  serialized_end=1194,
)


_EVENTBINARYOPTIONSMARKETUPDATE = _descriptor.Descriptor(
  name='EventBinaryOptionsMarketUpdate',
  full_name='injective.exchange.v1beta1.EventBinaryOptionsMarketUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='injective.exchange.v1beta1.EventBinaryOptionsMarketUpdate.market', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1196,
  serialized_end=1299,
)


_EVENTNEWSPOTORDERS = _descriptor.Descriptor(
  name='EventNewSpotOrders',
  full_name='injective.exchange.v1beta1.EventNewSpotOrders',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.EventNewSpotOrders.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buy_orders', full_name='injective.exchange.v1beta1.EventNewSpotOrders.buy_orders', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sell_orders', full_name='injective.exchange.v1beta1.EventNewSpotOrders.sell_orders', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1302,
  serialized_end=1470,
)


_EVENTNEWDERIVATIVEORDERS = _descriptor.Descriptor(
  name='EventNewDerivativeOrders',
  full_name='injective.exchange.v1beta1.EventNewDerivativeOrders',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.EventNewDerivativeOrders.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buy_orders', full_name='injective.exchange.v1beta1.EventNewDerivativeOrders.buy_orders', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sell_orders', full_name='injective.exchange.v1beta1.EventNewDerivativeOrders.sell_orders', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1473,
  serialized_end=1659,
)


_EVENTCANCELSPOTORDER = _descriptor.Descriptor(
  name='EventCancelSpotOrder',
  full_name='injective.exchange.v1beta1.EventCancelSpotOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.EventCancelSpotOrder.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order', full_name='injective.exchange.v1beta1.EventCancelSpotOrder.order', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1661,
  serialized_end=1767,
)


_EVENTSPOTMARKETUPDATE = _descriptor.Descriptor(
  name='EventSpotMarketUpdate',
  full_name='injective.exchange.v1beta1.EventSpotMarketUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='injective.exchange.v1beta1.EventSpotMarketUpdate.market', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1769,
  serialized_end=1854,
)


_EVENTPERPETUALMARKETUPDATE = _descriptor.Descriptor(
  name='EventPerpetualMarketUpdate',
  full_name='injective.exchange.v1beta1.EventPerpetualMarketUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='injective.exchange.v1beta1.EventPerpetualMarketUpdate.market', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perpetual_market_info', full_name='injective.exchange.v1beta1.EventPerpetualMarketUpdate.perpetual_market_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='funding', full_name='injective.exchange.v1beta1.EventPerpetualMarketUpdate.funding', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1857,
  serialized_end=2114,
)


_EVENTEXPIRYFUTURESMARKETUPDATE = _descriptor.Descriptor(
  name='EventExpiryFuturesMarketUpdate',
  full_name='injective.exchange.v1beta1.EventExpiryFuturesMarketUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='injective.exchange.v1beta1.EventExpiryFuturesMarketUpdate.market', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiry_futures_market_info', full_name='injective.exchange.v1beta1.EventExpiryFuturesMarketUpdate.expiry_futures_market_info', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2117,
  serialized_end=2312,
)


_EVENTPERPETUALMARKETFUNDINGUPDATE = _descriptor.Descriptor(
  name='EventPerpetualMarketFundingUpdate',
  full_name='injective.exchange.v1beta1.EventPerpetualMarketFundingUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.EventPerpetualMarketFundingUpdate.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='funding', full_name='injective.exchange.v1beta1.EventPerpetualMarketFundingUpdate.funding', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_hourly_funding', full_name='injective.exchange.v1beta1.EventPerpetualMarketFundingUpdate.is_hourly_funding', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='funding_rate', full_name='injective.exchange.v1beta1.EventPerpetualMarketFundingUpdate.funding_rate', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mark_price', full_name='injective.exchange.v1beta1.EventPerpetualMarketFundingUpdate.mark_price', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2315,
  serialized_end=2609,
)


_EVENTSUBACCOUNTDEPOSIT = _descriptor.Descriptor(
  name='EventSubaccountDeposit',
  full_name='injective.exchange.v1beta1.EventSubaccountDeposit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='src_address', full_name='injective.exchange.v1beta1.EventSubaccountDeposit.src_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.EventSubaccountDeposit.subaccount_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.exchange.v1beta1.EventSubaccountDeposit.amount', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2611,
  serialized_end=2728,
)


_EVENTSUBACCOUNTWITHDRAW = _descriptor.Descriptor(
  name='EventSubaccountWithdraw',
  full_name='injective.exchange.v1beta1.EventSubaccountWithdraw',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.EventSubaccountWithdraw.subaccount_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dst_address', full_name='injective.exchange.v1beta1.EventSubaccountWithdraw.dst_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.exchange.v1beta1.EventSubaccountWithdraw.amount', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2730,
  serialized_end=2848,
)


_EVENTSUBACCOUNTBALANCETRANSFER = _descriptor.Descriptor(
  name='EventSubaccountBalanceTransfer',
  full_name='injective.exchange.v1beta1.EventSubaccountBalanceTransfer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='src_subaccount_id', full_name='injective.exchange.v1beta1.EventSubaccountBalanceTransfer.src_subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dst_subaccount_id', full_name='injective.exchange.v1beta1.EventSubaccountBalanceTransfer.dst_subaccount_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.exchange.v1beta1.EventSubaccountBalanceTransfer.amount', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2851,
  serialized_end=2986,
)


_EVENTBATCHDEPOSITUPDATE = _descriptor.Descriptor(
  name='EventBatchDepositUpdate',
  full_name='injective.exchange.v1beta1.EventBatchDepositUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deposit_updates', full_name='injective.exchange.v1beta1.EventBatchDepositUpdate.deposit_updates', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2988,
  serialized_end=3081,
)


_DERIVATIVEMARKETORDERCANCEL = _descriptor.Descriptor(
  name='DerivativeMarketOrderCancel',
  full_name='injective.exchange.v1beta1.DerivativeMarketOrderCancel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_order', full_name='injective.exchange.v1beta1.DerivativeMarketOrderCancel.market_order', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cancel_quantity', full_name='injective.exchange.v1beta1.DerivativeMarketOrderCancel.cancel_quantity', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3084,
  serialized_end=3265,
)


_EVENTCANCELDERIVATIVEORDER = _descriptor.Descriptor(
  name='EventCancelDerivativeOrder',
  full_name='injective.exchange.v1beta1.EventCancelDerivativeOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.EventCancelDerivativeOrder.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isLimitCancel', full_name='injective.exchange.v1beta1.EventCancelDerivativeOrder.isLimitCancel', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit_order', full_name='injective.exchange.v1beta1.EventCancelDerivativeOrder.limit_order', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_order_cancel', full_name='injective.exchange.v1beta1.EventCancelDerivativeOrder.market_order_cancel', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3268,
  serialized_end=3507,
)


_EVENTFEEDISCOUNTSCHEDULE = _descriptor.Descriptor(
  name='EventFeeDiscountSchedule',
  full_name='injective.exchange.v1beta1.EventFeeDiscountSchedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='schedule', full_name='injective.exchange.v1beta1.EventFeeDiscountSchedule.schedule', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3509,
  serialized_end=3602,
)


_EVENTTRADINGREWARDCAMPAIGNUPDATE = _descriptor.Descriptor(
  name='EventTradingRewardCampaignUpdate',
  full_name='injective.exchange.v1beta1.EventTradingRewardCampaignUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='campaign_info', full_name='injective.exchange.v1beta1.EventTradingRewardCampaignUpdate.campaign_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='campaign_reward_pools', full_name='injective.exchange.v1beta1.EventTradingRewardCampaignUpdate.campaign_reward_pools', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3605,
  serialized_end=3796,
)


_EVENTTRADINGREWARDDISTRIBUTION = _descriptor.Descriptor(
  name='EventTradingRewardDistribution',
  full_name='injective.exchange.v1beta1.EventTradingRewardDistribution',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_rewards', full_name='injective.exchange.v1beta1.EventTradingRewardDistribution.account_rewards', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3798,
  serialized_end=3899,
)


_EVENTNEWCONDITIONALDERIVATIVEORDER = _descriptor.Descriptor(
  name='EventNewConditionalDerivativeOrder',
  full_name='injective.exchange.v1beta1.EventNewConditionalDerivativeOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.EventNewConditionalDerivativeOrder.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order', full_name='injective.exchange.v1beta1.EventNewConditionalDerivativeOrder.order', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hash', full_name='injective.exchange.v1beta1.EventNewConditionalDerivativeOrder.hash', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_market', full_name='injective.exchange.v1beta1.EventNewConditionalDerivativeOrder.is_market', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3902,
  serialized_end=4050,
)


_EVENTCANCELCONDITIONALDERIVATIVEORDER = _descriptor.Descriptor(
  name='EventCancelConditionalDerivativeOrder',
  full_name='injective.exchange.v1beta1.EventCancelConditionalDerivativeOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.EventCancelConditionalDerivativeOrder.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isLimitCancel', full_name='injective.exchange.v1beta1.EventCancelConditionalDerivativeOrder.isLimitCancel', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit_order', full_name='injective.exchange.v1beta1.EventCancelConditionalDerivativeOrder.limit_order', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_order', full_name='injective.exchange.v1beta1.EventCancelConditionalDerivativeOrder.market_order', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4053,
  serialized_end=4290,
)


_EVENTCONDITIONALDERIVATIVEORDERTRIGGER = _descriptor.Descriptor(
  name='EventConditionalDerivativeOrderTrigger',
  full_name='injective.exchange.v1beta1.EventConditionalDerivativeOrderTrigger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.EventConditionalDerivativeOrderTrigger.market_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isLimitTrigger', full_name='injective.exchange.v1beta1.EventConditionalDerivativeOrderTrigger.isLimitTrigger', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='triggered_order_hash', full_name='injective.exchange.v1beta1.EventConditionalDerivativeOrderTrigger.triggered_order_hash', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='placed_order_hash', full_name='injective.exchange.v1beta1.EventConditionalDerivativeOrderTrigger.placed_order_hash', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4293,
  serialized_end=4433,
)


_EVENTORDERFAIL = _descriptor.Descriptor(
  name='EventOrderFail',
  full_name='injective.exchange.v1beta1.EventOrderFail',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='injective.exchange.v1beta1.EventOrderFail.account', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hashes', full_name='injective.exchange.v1beta1.EventOrderFail.hashes', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags', full_name='injective.exchange.v1beta1.EventOrderFail.flags', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4435,
  serialized_end=4499,
)

_EVENTBATCHSPOTEXECUTION.fields_by_name['executionType'].enum_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._EXECUTIONTYPE
_EVENTBATCHSPOTEXECUTION.fields_by_name['trades'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._TRADELOG
_EVENTBATCHDERIVATIVEEXECUTION.fields_by_name['executionType'].enum_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._EXECUTIONTYPE
_EVENTBATCHDERIVATIVEEXECUTION.fields_by_name['trades'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVETRADELOG
_EVENTBATCHDERIVATIVEPOSITION.fields_by_name['positions'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._SUBACCOUNTPOSITION
_EVENTBINARYOPTIONSMARKETUPDATE.fields_by_name['market'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._BINARYOPTIONSMARKET
_EVENTNEWSPOTORDERS.fields_by_name['buy_orders'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._SPOTLIMITORDER
_EVENTNEWSPOTORDERS.fields_by_name['sell_orders'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._SPOTLIMITORDER
_EVENTNEWDERIVATIVEORDERS.fields_by_name['buy_orders'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVELIMITORDER
_EVENTNEWDERIVATIVEORDERS.fields_by_name['sell_orders'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVELIMITORDER
_EVENTCANCELSPOTORDER.fields_by_name['order'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._SPOTLIMITORDER
_EVENTSPOTMARKETUPDATE.fields_by_name['market'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._SPOTMARKET
_EVENTPERPETUALMARKETUPDATE.fields_by_name['market'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVEMARKET
_EVENTPERPETUALMARKETUPDATE.fields_by_name['perpetual_market_info'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._PERPETUALMARKETINFO
_EVENTPERPETUALMARKETUPDATE.fields_by_name['funding'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._PERPETUALMARKETFUNDING
_EVENTEXPIRYFUTURESMARKETUPDATE.fields_by_name['market'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVEMARKET
_EVENTEXPIRYFUTURESMARKETUPDATE.fields_by_name['expiry_futures_market_info'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._EXPIRYFUTURESMARKETINFO
_EVENTPERPETUALMARKETFUNDINGUPDATE.fields_by_name['funding'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._PERPETUALMARKETFUNDING
_EVENTSUBACCOUNTDEPOSIT.fields_by_name['amount'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_EVENTSUBACCOUNTWITHDRAW.fields_by_name['amount'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_EVENTSUBACCOUNTBALANCETRANSFER.fields_by_name['amount'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_EVENTBATCHDEPOSITUPDATE.fields_by_name['deposit_updates'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DEPOSITUPDATE
_DERIVATIVEMARKETORDERCANCEL.fields_by_name['market_order'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVEMARKETORDER
_EVENTCANCELDERIVATIVEORDER.fields_by_name['limit_order'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVELIMITORDER
_EVENTCANCELDERIVATIVEORDER.fields_by_name['market_order_cancel'].message_type = _DERIVATIVEMARKETORDERCANCEL
_EVENTFEEDISCOUNTSCHEDULE.fields_by_name['schedule'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._FEEDISCOUNTSCHEDULE
_EVENTTRADINGREWARDCAMPAIGNUPDATE.fields_by_name['campaign_info'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._TRADINGREWARDCAMPAIGNINFO
_EVENTTRADINGREWARDCAMPAIGNUPDATE.fields_by_name['campaign_reward_pools'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._CAMPAIGNREWARDPOOL
_EVENTTRADINGREWARDDISTRIBUTION.fields_by_name['account_rewards'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._ACCOUNTREWARDS
_EVENTNEWCONDITIONALDERIVATIVEORDER.fields_by_name['order'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVEORDER
_EVENTCANCELCONDITIONALDERIVATIVEORDER.fields_by_name['limit_order'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVELIMITORDER
_EVENTCANCELCONDITIONALDERIVATIVEORDER.fields_by_name['market_order'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVEMARKETORDER
DESCRIPTOR.message_types_by_name['EventBatchSpotExecution'] = _EVENTBATCHSPOTEXECUTION
DESCRIPTOR.message_types_by_name['EventBatchDerivativeExecution'] = _EVENTBATCHDERIVATIVEEXECUTION
DESCRIPTOR.message_types_by_name['EventLostFundsFromLiquidation'] = _EVENTLOSTFUNDSFROMLIQUIDATION
DESCRIPTOR.message_types_by_name['EventBatchDerivativePosition'] = _EVENTBATCHDERIVATIVEPOSITION
DESCRIPTOR.message_types_by_name['EventDerivativeMarketPaused'] = _EVENTDERIVATIVEMARKETPAUSED
DESCRIPTOR.message_types_by_name['EventBinaryOptionsMarketUpdate'] = _EVENTBINARYOPTIONSMARKETUPDATE
DESCRIPTOR.message_types_by_name['EventNewSpotOrders'] = _EVENTNEWSPOTORDERS
DESCRIPTOR.message_types_by_name['EventNewDerivativeOrders'] = _EVENTNEWDERIVATIVEORDERS
DESCRIPTOR.message_types_by_name['EventCancelSpotOrder'] = _EVENTCANCELSPOTORDER
DESCRIPTOR.message_types_by_name['EventSpotMarketUpdate'] = _EVENTSPOTMARKETUPDATE
DESCRIPTOR.message_types_by_name['EventPerpetualMarketUpdate'] = _EVENTPERPETUALMARKETUPDATE
DESCRIPTOR.message_types_by_name['EventExpiryFuturesMarketUpdate'] = _EVENTEXPIRYFUTURESMARKETUPDATE
DESCRIPTOR.message_types_by_name['EventPerpetualMarketFundingUpdate'] = _EVENTPERPETUALMARKETFUNDINGUPDATE
DESCRIPTOR.message_types_by_name['EventSubaccountDeposit'] = _EVENTSUBACCOUNTDEPOSIT
DESCRIPTOR.message_types_by_name['EventSubaccountWithdraw'] = _EVENTSUBACCOUNTWITHDRAW
DESCRIPTOR.message_types_by_name['EventSubaccountBalanceTransfer'] = _EVENTSUBACCOUNTBALANCETRANSFER
DESCRIPTOR.message_types_by_name['EventBatchDepositUpdate'] = _EVENTBATCHDEPOSITUPDATE
DESCRIPTOR.message_types_by_name['DerivativeMarketOrderCancel'] = _DERIVATIVEMARKETORDERCANCEL
DESCRIPTOR.message_types_by_name['EventCancelDerivativeOrder'] = _EVENTCANCELDERIVATIVEORDER
DESCRIPTOR.message_types_by_name['EventFeeDiscountSchedule'] = _EVENTFEEDISCOUNTSCHEDULE
DESCRIPTOR.message_types_by_name['EventTradingRewardCampaignUpdate'] = _EVENTTRADINGREWARDCAMPAIGNUPDATE
DESCRIPTOR.message_types_by_name['EventTradingRewardDistribution'] = _EVENTTRADINGREWARDDISTRIBUTION
DESCRIPTOR.message_types_by_name['EventNewConditionalDerivativeOrder'] = _EVENTNEWCONDITIONALDERIVATIVEORDER
DESCRIPTOR.message_types_by_name['EventCancelConditionalDerivativeOrder'] = _EVENTCANCELCONDITIONALDERIVATIVEORDER
DESCRIPTOR.message_types_by_name['EventConditionalDerivativeOrderTrigger'] = _EVENTCONDITIONALDERIVATIVEORDERTRIGGER
DESCRIPTOR.message_types_by_name['EventOrderFail'] = _EVENTORDERFAIL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EventBatchSpotExecution = _reflection.GeneratedProtocolMessageType('EventBatchSpotExecution', (_message.Message,), {
  'DESCRIPTOR' : _EVENTBATCHSPOTEXECUTION,
  '__module__' : 'injective.exchange.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventBatchSpotExecution)
  })
_sym_db.RegisterMessage(EventBatchSpotExecution)

EventBatchDerivativeExecution = _reflection.GeneratedProtocolMessageType('EventBatchDerivativeExecution', (_message.Message,), {
  'DESCRIPTOR' : _EVENTBATCHDERIVATIVEEXECUTION,
  '__module__' : 'injective.exchange.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventBatchDerivativeExecution)
  })
_sym_db.RegisterMessage(EventBatchDerivativeExecution)

EventLostFundsFromLiquidation = _reflection.GeneratedProtocolMessageType('EventLostFundsFromLiquidation', (_message.Message,), {
  'DESCRIPTOR' : _EVENTLOSTFUNDSFROMLIQUIDATION,
  '__module__' : 'injective.exchange.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventLostFundsFromLiquidation)
  })
_sym_db.RegisterMessage(EventLostFundsFromLiquidation)

EventBatchDerivativePosition = _reflection.GeneratedProtocolMessageType('EventBatchDerivativePosition', (_message.Message,), {
  'DESCRIPTOR' : _EVENTBATCHDERIVATIVEPOSITION,
  '__module__' : 'injective.exchange.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventBatchDerivativePosition)
  })
_sym_db.RegisterMessage(EventBatchDerivativePosition)

EventDerivativeMarketPaused = _reflection.GeneratedProtocolMessageType('EventDerivativeMarketPaused', (_message.Message,), {
  'DESCRIPTOR' : _EVENTDERIVATIVEMARKETPAUSED,
  '__module__' : 'injective.exchange.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventDerivativeMarketPaused)
  })
_sym_db.RegisterMessage(EventDerivativeMarketPaused)

EventBinaryOptionsMarketUpdate = _reflection.GeneratedProtocolMessageType('EventBinaryOptionsMarketUpdate', (_message.Message,), {
  'DESCRIPTOR' : _EVENTBINARYOPTIONSMARKETUPDATE,
  '__module__' : 'injective.exchange.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventBinaryOptionsMarketUpdate)
  })
_sym_db.RegisterMessage(EventBinaryOptionsMarketUpdate)

EventNewSpotOrders = _reflection.GeneratedProtocolMessageType('EventNewSpotOrders', (_message.Message,), {
  'DESCRIPTOR' : _EVENTNEWSPOTORDERS,
  '__module__' : 'injective.exchange.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventNewSpotOrders)
  })
_sym_db.RegisterMessage(EventNewSpotOrders)

EventNewDerivativeOrders = _reflection.GeneratedProtocolMessageType('EventNewDerivativeOrders', (_message.Message,), {
  'DESCRIPTOR' : _EVENTNEWDERIVATIVEORDERS,
  '__module__' : 'injective.exchange.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventNewDerivativeOrders)
  })
_sym_db.RegisterMessage(EventNewDerivativeOrders)

EventCancelSpotOrder = _reflection.GeneratedProtocolMessageType('EventCancelSpotOrder', (_message.Message,), {
  'DESCRIPTOR' : _EVENTCANCELSPOTORDER,
  '__module__' : 'injective.exchange.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventCancelSpotOrder)
  })
_sym_db.RegisterMessage(EventCancelSpotOrder)

EventSpotMarketUpdate = _reflection.GeneratedProtocolMessageType('EventSpotMarketUpdate', (_message.Message,), {
  'DESCRIPTOR' : _EVENTSPOTMARKETUPDATE,
  '__module__' : 'injective.exchange.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventSpotMarketUpdate)
  })
_sym_db.RegisterMessage(EventSpotMarketUpdate)

EventPerpetualMarketUpdate = _reflection.GeneratedProtocolMessageType('EventPerpetualMarketUpdate', (_message.Message,), {
  'DESCRIPTOR' : _EVENTPERPETUALMARKETUPDATE,
  '__module__' : 'injective.exchange.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventPerpetualMarketUpdate)
  })
_sym_db.RegisterMessage(EventPerpetualMarketUpdate)

EventExpiryFuturesMarketUpdate = _reflection.GeneratedProtocolMessageType('EventExpiryFuturesMarketUpdate', (_message.Message,), {
  'DESCRIPTOR' : _EVENTEXPIRYFUTURESMARKETUPDATE,
  '__module__' : 'injective.exchange.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventExpiryFuturesMarketUpdate)
  })
_sym_db.RegisterMessage(EventExpiryFuturesMarketUpdate)

EventPerpetualMarketFundingUpdate = _reflection.GeneratedProtocolMessageType('EventPerpetualMarketFundingUpdate', (_message.Message,), {
  'DESCRIPTOR' : _EVENTPERPETUALMARKETFUNDINGUPDATE,
  '__module__' : 'injective.exchange.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventPerpetualMarketFundingUpdate)
  })
_sym_db.RegisterMessage(EventPerpetualMarketFundingUpdate)

EventSubaccountDeposit = _reflection.GeneratedProtocolMessageType('EventSubaccountDeposit', (_message.Message,), {
  'DESCRIPTOR' : _EVENTSUBACCOUNTDEPOSIT,
  '__module__' : 'injective.exchange.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventSubaccountDeposit)
  })
_sym_db.RegisterMessage(EventSubaccountDeposit)

EventSubaccountWithdraw = _reflection.GeneratedProtocolMessageType('EventSubaccountWithdraw', (_message.Message,), {
  'DESCRIPTOR' : _EVENTSUBACCOUNTWITHDRAW,
  '__module__' : 'injective.exchange.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventSubaccountWithdraw)
  })
_sym_db.RegisterMessage(EventSubaccountWithdraw)

EventSubaccountBalanceTransfer = _reflection.GeneratedProtocolMessageType('EventSubaccountBalanceTransfer', (_message.Message,), {
  'DESCRIPTOR' : _EVENTSUBACCOUNTBALANCETRANSFER,
  '__module__' : 'injective.exchange.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventSubaccountBalanceTransfer)
  })
_sym_db.RegisterMessage(EventSubaccountBalanceTransfer)

EventBatchDepositUpdate = _reflection.GeneratedProtocolMessageType('EventBatchDepositUpdate', (_message.Message,), {
  'DESCRIPTOR' : _EVENTBATCHDEPOSITUPDATE,
  '__module__' : 'injective.exchange.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventBatchDepositUpdate)
  })
_sym_db.RegisterMessage(EventBatchDepositUpdate)

DerivativeMarketOrderCancel = _reflection.GeneratedProtocolMessageType('DerivativeMarketOrderCancel', (_message.Message,), {
  'DESCRIPTOR' : _DERIVATIVEMARKETORDERCANCEL,
  '__module__' : 'injective.exchange.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.DerivativeMarketOrderCancel)
  })
_sym_db.RegisterMessage(DerivativeMarketOrderCancel)

EventCancelDerivativeOrder = _reflection.GeneratedProtocolMessageType('EventCancelDerivativeOrder', (_message.Message,), {
  'DESCRIPTOR' : _EVENTCANCELDERIVATIVEORDER,
  '__module__' : 'injective.exchange.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventCancelDerivativeOrder)
  })
_sym_db.RegisterMessage(EventCancelDerivativeOrder)

EventFeeDiscountSchedule = _reflection.GeneratedProtocolMessageType('EventFeeDiscountSchedule', (_message.Message,), {
  'DESCRIPTOR' : _EVENTFEEDISCOUNTSCHEDULE,
  '__module__' : 'injective.exchange.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventFeeDiscountSchedule)
  })
_sym_db.RegisterMessage(EventFeeDiscountSchedule)

EventTradingRewardCampaignUpdate = _reflection.GeneratedProtocolMessageType('EventTradingRewardCampaignUpdate', (_message.Message,), {
  'DESCRIPTOR' : _EVENTTRADINGREWARDCAMPAIGNUPDATE,
  '__module__' : 'injective.exchange.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventTradingRewardCampaignUpdate)
  })
_sym_db.RegisterMessage(EventTradingRewardCampaignUpdate)

EventTradingRewardDistribution = _reflection.GeneratedProtocolMessageType('EventTradingRewardDistribution', (_message.Message,), {
  'DESCRIPTOR' : _EVENTTRADINGREWARDDISTRIBUTION,
  '__module__' : 'injective.exchange.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventTradingRewardDistribution)
  })
_sym_db.RegisterMessage(EventTradingRewardDistribution)

EventNewConditionalDerivativeOrder = _reflection.GeneratedProtocolMessageType('EventNewConditionalDerivativeOrder', (_message.Message,), {
  'DESCRIPTOR' : _EVENTNEWCONDITIONALDERIVATIVEORDER,
  '__module__' : 'injective.exchange.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventNewConditionalDerivativeOrder)
  })
_sym_db.RegisterMessage(EventNewConditionalDerivativeOrder)

EventCancelConditionalDerivativeOrder = _reflection.GeneratedProtocolMessageType('EventCancelConditionalDerivativeOrder', (_message.Message,), {
  'DESCRIPTOR' : _EVENTCANCELCONDITIONALDERIVATIVEORDER,
  '__module__' : 'injective.exchange.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventCancelConditionalDerivativeOrder)
  })
_sym_db.RegisterMessage(EventCancelConditionalDerivativeOrder)

EventConditionalDerivativeOrderTrigger = _reflection.GeneratedProtocolMessageType('EventConditionalDerivativeOrderTrigger', (_message.Message,), {
  'DESCRIPTOR' : _EVENTCONDITIONALDERIVATIVEORDERTRIGGER,
  '__module__' : 'injective.exchange.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventConditionalDerivativeOrderTrigger)
  })
_sym_db.RegisterMessage(EventConditionalDerivativeOrderTrigger)

EventOrderFail = _reflection.GeneratedProtocolMessageType('EventOrderFail', (_message.Message,), {
  'DESCRIPTOR' : _EVENTORDERFAIL,
  '__module__' : 'injective.exchange.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventOrderFail)
  })
_sym_db.RegisterMessage(EventOrderFail)


DESCRIPTOR._options = None
_EVENTBATCHDERIVATIVEEXECUTION.fields_by_name['cumulative_funding']._options = None
_EVENTLOSTFUNDSFROMLIQUIDATION.fields_by_name['lost_funds_from_available_during_payout']._options = None
_EVENTLOSTFUNDSFROMLIQUIDATION.fields_by_name['lost_funds_from_order_cancels']._options = None
_EVENTBINARYOPTIONSMARKETUPDATE.fields_by_name['market']._options = None
_EVENTCANCELSPOTORDER.fields_by_name['order']._options = None
_EVENTSPOTMARKETUPDATE.fields_by_name['market']._options = None
_EVENTPERPETUALMARKETUPDATE.fields_by_name['market']._options = None
_EVENTPERPETUALMARKETUPDATE.fields_by_name['perpetual_market_info']._options = None
_EVENTPERPETUALMARKETUPDATE.fields_by_name['funding']._options = None
_EVENTEXPIRYFUTURESMARKETUPDATE.fields_by_name['market']._options = None
_EVENTEXPIRYFUTURESMARKETUPDATE.fields_by_name['expiry_futures_market_info']._options = None
_EVENTPERPETUALMARKETFUNDINGUPDATE.fields_by_name['funding']._options = None
_EVENTPERPETUALMARKETFUNDINGUPDATE.fields_by_name['funding_rate']._options = None
_EVENTPERPETUALMARKETFUNDINGUPDATE.fields_by_name['mark_price']._options = None
_EVENTSUBACCOUNTDEPOSIT.fields_by_name['amount']._options = None
_EVENTSUBACCOUNTWITHDRAW.fields_by_name['amount']._options = None
_EVENTSUBACCOUNTBALANCETRANSFER.fields_by_name['amount']._options = None
_DERIVATIVEMARKETORDERCANCEL.fields_by_name['market_order']._options = None
_DERIVATIVEMARKETORDERCANCEL.fields_by_name['cancel_quantity']._options = None
_EVENTCANCELDERIVATIVEORDER.fields_by_name['limit_order']._options = None
_EVENTCANCELDERIVATIVEORDER.fields_by_name['market_order_cancel']._options = None
_EVENTCANCELCONDITIONALDERIVATIVEORDER.fields_by_name['limit_order']._options = None
_EVENTCANCELCONDITIONALDERIVATIVEORDER.fields_by_name['market_order']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/base/snapshots/v1beta1/snapshot.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cosmos/base/snapshots/v1beta1/snapshot.proto',
  package='cosmos.base.snapshots.v1beta1',
  syntax='proto3',
  serialized_options=b'Z,github.com/cosmos/cosmos-sdk/snapshots/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,cosmos/base/snapshots/v1beta1/snapshot.proto\x12\x1d\x63osmos.base.snapshots.v1beta1\x1a\x14gogoproto/gogo.proto\"\x89\x01\n\x08Snapshot\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\r\x12\x0e\n\x06\x63hunks\x18\x03 \x01(\r\x12\x0c\n\x04hash\x18\x04 \x01(\x0c\x12?\n\x08metadata\x18\x05 \x01(\x0b\x32\'.cosmos.base.snapshots.v1beta1.MetadataB\x04\xc8\xde\x1f\x00\" \n\x08Metadata\x12\x14\n\x0c\x63hunk_hashes\x18\x01 \x03(\x0c\"\xc5\x02\n\x0cSnapshotItem\x12\x41\n\x05store\x18\x01 \x01(\x0b\x32\x30.cosmos.base.snapshots.v1beta1.SnapshotStoreItemH\x00\x12I\n\x04iavl\x18\x02 \x01(\x0b\x32/.cosmos.base.snapshots.v1beta1.SnapshotIAVLItemB\x08\xe2\xde\x1f\x04IAVLH\x00\x12I\n\textension\x18\x03 \x01(\x0b\x32\x34.cosmos.base.snapshots.v1beta1.SnapshotExtensionMetaH\x00\x12T\n\x11\x65xtension_payload\x18\x04 \x01(\x0b\x32\x37.cosmos.base.snapshots.v1beta1.SnapshotExtensionPayloadH\x00\x42\x06\n\x04item\"!\n\x11SnapshotStoreItem\x12\x0c\n\x04name\x18\x01 \x01(\t\"O\n\x10SnapshotIAVLItem\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\x0f\n\x07version\x18\x03 \x01(\x03\x12\x0e\n\x06height\x18\x04 \x01(\x05\"5\n\x15SnapshotExtensionMeta\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\r\"+\n\x18SnapshotExtensionPayload\x12\x0f\n\x07payload\x18\x01 \x01(\x0c\x42.Z,github.com/cosmos/cosmos-sdk/snapshots/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,])




_SNAPSHOT = _descriptor.Descriptor(
  name='Snapshot',
  full_name='cosmos.base.snapshots.v1beta1.Snapshot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='height', full_name='cosmos.base.snapshots.v1beta1.Snapshot.height', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format', full_name='cosmos.base.snapshots.v1beta1.Snapshot.format', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chunks', full_name='cosmos.base.snapshots.v1beta1.Snapshot.chunks', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hash', full_name='cosmos.base.snapshots.v1beta1.Snapshot.hash', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='cosmos.base.snapshots.v1beta1.Snapshot.metadata', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=102,
  serialized_end=239,
)


_METADATA = _descriptor.Descriptor(
  name='Metadata',
  full_name='cosmos.base.snapshots.v1beta1.Metadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chunk_hashes', full_name='cosmos.base.snapshots.v1beta1.Metadata.chunk_hashes', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=241,
  serialized_end=273,
)


_SNAPSHOTITEM = _descriptor.Descriptor(
  name='SnapshotItem',
  full_name='cosmos.base.snapshots.v1beta1.SnapshotItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='store', full_name='cosmos.base.snapshots.v1beta1.SnapshotItem.store', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iavl', full_name='cosmos.base.snapshots.v1beta1.SnapshotItem.iavl', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\004IAVL', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extension', full_name='cosmos.base.snapshots.v1beta1.SnapshotItem.extension', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extension_payload', full_name='cosmos.base.snapshots.v1beta1.SnapshotItem.extension_payload', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='item', full_name='cosmos.base.snapshots.v1beta1.SnapshotItem.item',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=276,
  serialized_end=601,
)


_SNAPSHOTSTOREITEM = _descriptor.Descriptor(
  name='SnapshotStoreItem',
  full_name='cosmos.base.snapshots.v1beta1.SnapshotStoreItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='cosmos.base.snapshots.v1beta1.SnapshotStoreItem.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=603,
  serialized_end=636,
)


_SNAPSHOTIAVLITEM = _descriptor.Descriptor(
  name='SnapshotIAVLItem',
  full_name='cosmos.base.snapshots.v1beta1.SnapshotIAVLItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='cosmos.base.snapshots.v1beta1.SnapshotIAVLItem.key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='cosmos.base.snapshots.v1beta1.SnapshotIAVLItem.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='cosmos.base.snapshots.v1beta1.SnapshotIAVLItem.version', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='cosmos.base.snapshots.v1beta1.SnapshotIAVLItem.height', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=638,
  serialized_end=717,
)


_SNAPSHOTEXTENSIONMETA = _descriptor.Descriptor(
  name='SnapshotExtensionMeta',
  full_name='cosmos.base.snapshots.v1beta1.SnapshotExtensionMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='cosmos.base.snapshots.v1beta1.SnapshotExtensionMeta.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format', full_name='cosmos.base.snapshots.v1beta1.SnapshotExtensionMeta.format', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=719,
  serialized_end=772,
)


_SNAPSHOTEXTENSIONPAYLOAD = _descriptor.Descriptor(
  name='SnapshotExtensionPayload',
  full_name='cosmos.base.snapshots.v1beta1.SnapshotExtensionPayload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='payload', full_name='cosmos.base.snapshots.v1beta1.SnapshotExtensionPayload.payload', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=774,
  serialized_end=817,
)

_SNAPSHOT.fields_by_name['metadata'].message_type = _METADATA
_SNAPSHOTITEM.fields_by_name['store'].message_type = _SNAPSHOTSTOREITEM
_SNAPSHOTITEM.fields_by_name['iavl'].message_type = _SNAPSHOTIAVLITEM
_SNAPSHOTITEM.fields_by_name['extension'].message_type = _SNAPSHOTEXTENSIONMETA
_SNAPSHOTITEM.fields_by_name['extension_payload'].message_type = _SNAPSHOTEXTENSIONPAYLOAD
_SNAPSHOTITEM.oneofs_by_name['item'].fields.append(
  _SNAPSHOTITEM.fields_by_name['store'])
_SNAPSHOTITEM.fields_by_name['store'].containing_oneof = _SNAPSHOTITEM.oneofs_by_name['item']
_SNAPSHOTITEM.oneofs_by_name['item'].fields.append(
  _SNAPSHOTITEM.fields_by_name['iavl'])
_SNAPSHOTITEM.fields_by_name['iavl'].containing_oneof = _SNAPSHOTITEM.oneofs_by_name['item']
_SNAPSHOTITEM.oneofs_by_name['item'].fields.append(
  _SNAPSHOTITEM.fields_by_name['extension'])
_SNAPSHOTITEM.fields_by_name['extension'].containing_oneof = _SNAPSHOTITEM.oneofs_by_name['item']
_SNAPSHOTITEM.oneofs_by_name['item'].fields.append(
  _SNAPSHOTITEM.fields_by_name['extension_payload'])
_SNAPSHOTITEM.fields_by_name['extension_payload'].containing_oneof = _SNAPSHOTITEM.oneofs_by_name['item']
DESCRIPTOR.message_types_by_name['Snapshot'] = _SNAPSHOT
DESCRIPTOR.message_types_by_name['Metadata'] = _METADATA
DESCRIPTOR.message_types_by_name['SnapshotItem'] = _SNAPSHOTITEM
DESCRIPTOR.message_types_by_name['SnapshotStoreItem'] = _SNAPSHOTSTOREITEM
DESCRIPTOR.message_types_by_name['SnapshotIAVLItem'] = _SNAPSHOTIAVLITEM
DESCRIPTOR.message_types_by_name['SnapshotExtensionMeta'] = _SNAPSHOTEXTENSIONMETA
DESCRIPTOR.message_types_by_name['SnapshotExtensionPayload'] = _SNAPSHOTEXTENSIONPAYLOAD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Snapshot = _reflection.GeneratedProtocolMessageType('Snapshot', (_message.Message,), {
  'DESCRIPTOR' : _SNAPSHOT,
  '__module__' : 'cosmos.base.snapshots.v1beta1.snapshot_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.snapshots.v1beta1.Snapshot)
  })
_sym_db.RegisterMessage(Snapshot)

Metadata = _reflection.GeneratedProtocolMessageType('Metadata', (_message.Message,), {
  'DESCRIPTOR' : _METADATA,
  '__module__' : 'cosmos.base.snapshots.v1beta1.snapshot_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.snapshots.v1beta1.Metadata)
  })
_sym_db.RegisterMessage(Metadata)

SnapshotItem = _reflection.GeneratedProtocolMessageType('SnapshotItem', (_message.Message,), {
  'DESCRIPTOR' : _SNAPSHOTITEM,
  '__module__' : 'cosmos.base.snapshots.v1beta1.snapshot_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.snapshots.v1beta1.SnapshotItem)
  })
_sym_db.RegisterMessage(SnapshotItem)

SnapshotStoreItem = _reflection.GeneratedProtocolMessageType('SnapshotStoreItem', (_message.Message,), {
  'DESCRIPTOR' : _SNAPSHOTSTOREITEM,
  '__module__' : 'cosmos.base.snapshots.v1beta1.snapshot_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.snapshots.v1beta1.SnapshotStoreItem)
  })
_sym_db.RegisterMessage(SnapshotStoreItem)

SnapshotIAVLItem = _reflection.GeneratedProtocolMessageType('SnapshotIAVLItem', (_message.Message,), {
  'DESCRIPTOR' : _SNAPSHOTIAVLITEM,
  '__module__' : 'cosmos.base.snapshots.v1beta1.snapshot_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.snapshots.v1beta1.SnapshotIAVLItem)
  })
_sym_db.RegisterMessage(SnapshotIAVLItem)

SnapshotExtensionMeta = _reflection.GeneratedProtocolMessageType('SnapshotExtensionMeta', (_message.Message,), {
  'DESCRIPTOR' : _SNAPSHOTEXTENSIONMETA,
  '__module__' : 'cosmos.base.snapshots.v1beta1.snapshot_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.snapshots.v1beta1.SnapshotExtensionMeta)
  })
_sym_db.RegisterMessage(SnapshotExtensionMeta)

SnapshotExtensionPayload = _reflection.GeneratedProtocolMessageType('SnapshotExtensionPayload', (_message.Message,), {
  'DESCRIPTOR' : _SNAPSHOTEXTENSIONPAYLOAD,
  '__module__' : 'cosmos.base.snapshots.v1beta1.snapshot_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.snapshots.v1beta1.SnapshotExtensionPayload)
  })
_sym_db.RegisterMessage(SnapshotExtensionPayload)


DESCRIPTOR._options = None
_SNAPSHOT.fields_by_name['metadata']._options = None
_SNAPSHOTITEM.fields_by_name['iavl']._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from exchange import injective_accounts_rpc_pb2 as exchange_dot_injective__accounts__rpc__pb2


class InjectiveAccountsRPCStub(object):
    """InjectiveAccountsRPC defines gRPC API of Exchange Accounts provider.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Portfolio = channel.unary_unary(
                '/injective_accounts_rpc.InjectiveAccountsRPC/Portfolio',
                request_serializer=exchange_dot_injective__accounts__rpc__pb2.PortfolioRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__accounts__rpc__pb2.PortfolioResponse.FromString,
                )
        self.OrderStates = channel.unary_unary(
                '/injective_accounts_rpc.InjectiveAccountsRPC/OrderStates',
                request_serializer=exchange_dot_injective__accounts__rpc__pb2.OrderStatesRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__accounts__rpc__pb2.OrderStatesResponse.FromString,
                )
        self.SubaccountsList = channel.unary_unary(
                '/injective_accounts_rpc.InjectiveAccountsRPC/SubaccountsList',
                request_serializer=exchange_dot_injective__accounts__rpc__pb2.SubaccountsListRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__accounts__rpc__pb2.SubaccountsListResponse.FromString,
                )
        self.SubaccountBalancesList = channel.unary_unary(
                '/injective_accounts_rpc.InjectiveAccountsRPC/SubaccountBalancesList',
                request_serializer=exchange_dot_injective__accounts__rpc__pb2.SubaccountBalancesListRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__accounts__rpc__pb2.SubaccountBalancesListResponse.FromString,
                )
        self.SubaccountBalanceEndpoint = channel.unary_unary(
                '/injective_accounts_rpc.InjectiveAccountsRPC/SubaccountBalanceEndpoint',
                request_serializer=exchange_dot_injective__accounts__rpc__pb2.SubaccountBalanceRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__accounts__rpc__pb2.SubaccountBalanceResponse.FromString,
                )
        self.StreamSubaccountBalance = channel.unary_stream(
                '/injective_accounts_rpc.InjectiveAccountsRPC/StreamSubaccountBalance',
                request_serializer=exchange_dot_injective__accounts__rpc__pb2.StreamSubaccountBalanceRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__accounts__rpc__pb2.StreamSubaccountBalanceResponse.FromString,
                )
        self.SubaccountHistory = channel.unary_unary(
                '/injective_accounts_rpc.InjectiveAccountsRPC/SubaccountHistory',
                request_serializer=exchange_dot_injective__accounts__rpc__pb2.SubaccountHistoryRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__accounts__rpc__pb2.SubaccountHistoryResponse.FromString,
                )
        self.SubaccountOrderSummary = channel.unary_unary(
                '/injective_accounts_rpc.InjectiveAccountsRPC/SubaccountOrderSummary',
                request_serializer=exchange_dot_injective__accounts__rpc__pb2.SubaccountOrderSummaryRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__accounts__rpc__pb2.SubaccountOrderSummaryResponse.FromString,
                )
        self.Rewards = channel.unary_unary(
                '/injective_accounts_rpc.InjectiveAccountsRPC/Rewards',
                request_serializer=exchange_dot_injective__accounts__rpc__pb2.RewardsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__accounts__rpc__pb2.RewardsResponse.FromString,
                )


class InjectiveAccountsRPCServicer(object):
    """InjectiveAccountsRPC defines gRPC API of Exchange Accounts provider.
    """

    def Portfolio(self, request, context):
        """Provide the account's portfolio value in USD.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OrderStates(self, request, context):
        """List order states by order hashes
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubaccountsList(self, request, context):
        """List all subaccounts IDs of an account address
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubaccountBalancesList(self, request, context):
        """List subaccount balances for the provided denoms.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubaccountBalanceEndpoint(self, request, context):
        """Gets a balance for specific coin denom
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamSubaccountBalance(self, request, context):
        """StreamSubaccountBalance streams new balance changes for a specified
        subaccount and denoms. If no denoms are provided, all denom changes are
        streamed.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubaccountHistory(self, request, context):
        """Get subaccount's deposits and withdrawals history
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubaccountOrderSummary(self, request, context):
        """Get subaccount's orders summary
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Rewards(self, request, context):
        """Provide historical trading rewards
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InjectiveAccountsRPCServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Portfolio': grpc.unary_unary_rpc_method_handler(
                    servicer.Portfolio,
                    request_deserializer=exchange_dot_injective__accounts__rpc__pb2.PortfolioRequest.FromString,
                    response_serializer=exchange_dot_injective__accounts__rpc__pb2.PortfolioResponse.SerializeToString,
            ),
            'OrderStates': grpc.unary_unary_rpc_method_handler(
                    servicer.OrderStates,
                    request_deserializer=exchange_dot_injective__accounts__rpc__pb2.OrderStatesRequest.FromString,
                    response_serializer=exchange_dot_injective__accounts__rpc__pb2.OrderStatesResponse.SerializeToString,
            ),
            'SubaccountsList': grpc.unary_unary_rpc_method_handler(
                    servicer.SubaccountsList,
                    request_deserializer=exchange_dot_injective__accounts__rpc__pb2.SubaccountsListRequest.FromString,
                    response_serializer=exchange_dot_injective__accounts__rpc__pb2.SubaccountsListResponse.SerializeToString,
            ),
            'SubaccountBalancesList': grpc.unary_unary_rpc_method_handler(
                    servicer.SubaccountBalancesList,
                    request_deserializer=exchange_dot_injective__accounts__rpc__pb2.SubaccountBalancesListRequest.FromString,
                    response_serializer=exchange_dot_injective__accounts__rpc__pb2.SubaccountBalancesListResponse.SerializeToString,
            ),
            'SubaccountBalanceEndpoint': grpc.unary_unary_rpc_method_handler(
                    servicer.SubaccountBalanceEndpoint,
                    request_deserializer=exchange_dot_injective__accounts__rpc__pb2.SubaccountBalanceRequest.FromString,
                    response_serializer=exchange_dot_injective__accounts__rpc__pb2.SubaccountBalanceResponse.SerializeToString,
            ),
            'StreamSubaccountBalance': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamSubaccountBalance,
                    request_deserializer=exchange_dot_injective__accounts__rpc__pb2.StreamSubaccountBalanceRequest.FromString,
                    response_serializer=exchange_dot_injective__accounts__rpc__pb2.StreamSubaccountBalanceResponse.SerializeToString,
            ),
            'SubaccountHistory': grpc.unary_unary_rpc_method_handler(
                    servicer.SubaccountHistory,
                    request_deserializer=exchange_dot_injective__accounts__rpc__pb2.SubaccountHistoryRequest.FromString,
                    response_serializer=exchange_dot_injective__accounts__rpc__pb2.SubaccountHistoryResponse.SerializeToString,
            ),
            'SubaccountOrderSummary': grpc.unary_unary_rpc_method_handler(
                    servicer.SubaccountOrderSummary,
                    request_deserializer=exchange_dot_injective__accounts__rpc__pb2.SubaccountOrderSummaryRequest.FromString,
                    response_serializer=exchange_dot_injective__accounts__rpc__pb2.SubaccountOrderSummaryResponse.SerializeToString,
            ),
            'Rewards': grpc.unary_unary_rpc_method_handler(
                    servicer.Rewards,
                    request_deserializer=exchange_dot_injective__accounts__rpc__pb2.RewardsRequest.FromString,
                    response_serializer=exchange_dot_injective__accounts__rpc__pb2.RewardsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective_accounts_rpc.InjectiveAccountsRPC', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class InjectiveAccountsRPC(object):
    """InjectiveAccountsRPC defines gRPC API of Exchange Accounts provider.
    """

    @staticmethod
    def Portfolio(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_accounts_rpc.InjectiveAccountsRPC/Portfolio',
            exchange_dot_injective__accounts__rpc__pb2.PortfolioRequest.SerializeToString,
            exchange_dot_injective__accounts__rpc__pb2.PortfolioResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OrderStates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_accounts_rpc.InjectiveAccountsRPC/OrderStates',
            exchange_dot_injective__accounts__rpc__pb2.OrderStatesRequest.SerializeToString,
            exchange_dot_injective__accounts__rpc__pb2.OrderStatesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SubaccountsList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_accounts_rpc.InjectiveAccountsRPC/SubaccountsList',
            exchange_dot_injective__accounts__rpc__pb2.SubaccountsListRequest.SerializeToString,
            exchange_dot_injective__accounts__rpc__pb2.SubaccountsListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SubaccountBalancesList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_accounts_rpc.InjectiveAccountsRPC/SubaccountBalancesList',
            exchange_dot_injective__accounts__rpc__pb2.SubaccountBalancesListRequest.SerializeToString,
            exchange_dot_injective__accounts__rpc__pb2.SubaccountBalancesListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SubaccountBalanceEndpoint(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_accounts_rpc.InjectiveAccountsRPC/SubaccountBalanceEndpoint',
            exchange_dot_injective__accounts__rpc__pb2.SubaccountBalanceRequest.SerializeToString,
            exchange_dot_injective__accounts__rpc__pb2.SubaccountBalanceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamSubaccountBalance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/injective_accounts_rpc.InjectiveAccountsRPC/StreamSubaccountBalance',
            exchange_dot_injective__accounts__rpc__pb2.StreamSubaccountBalanceRequest.SerializeToString,
            exchange_dot_injective__accounts__rpc__pb2.StreamSubaccountBalanceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SubaccountHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_accounts_rpc.InjectiveAccountsRPC/SubaccountHistory',
            exchange_dot_injective__accounts__rpc__pb2.SubaccountHistoryRequest.SerializeToString,
            exchange_dot_injective__accounts__rpc__pb2.SubaccountHistoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SubaccountOrderSummary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_accounts_rpc.InjectiveAccountsRPC/SubaccountOrderSummary',
            exchange_dot_injective__accounts__rpc__pb2.SubaccountOrderSummaryRequest.SerializeToString,
            exchange_dot_injective__accounts__rpc__pb2.SubaccountOrderSummaryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Rewards(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_accounts_rpc.InjectiveAccountsRPC/Rewards',
            exchange_dot_injective__accounts__rpc__pb2.RewardsRequest.SerializeToString,
            exchange_dot_injective__accounts__rpc__pb2.RewardsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
